@@ -27,7 +27,7 @@ from typing import Callable, Dict, Tuple, List, Optional
 from builtins import enumerate, reversed
 from .error import NotFound, InvalidToken
 from bale import (Message, Update, User, Components, RemoveMenuKeyboard, Chat, Price, ChatMember, HTTPClient, Updater,
-                  Photo, Document, Location, ContactMessage, Video, Audio)
+                  Photo, Document, Location, ContactMessage, Video, Audio, InputFile)
 
 __all__ = (
     "Bot"
@@ -73,7 +73,7 @@ class Bot:
 
     def __init__(self, token: str, **kwargs):
         if not isinstance(token, str):
-            raise InvalidToken("token must be type of the str")
+            raise InvalidToken()
         self.loop = _loop
         self.token = token
         self.http: HTTPClient = HTTPClient(self.loop, token)
@@ -331,6 +331,7 @@ class Bot:
         return Message.from_dict(data=response.result, bot=self)
 
     async def send_document(self, chat_id: str | int, document: bytes | str | "Document", *,
+                            file_name: Optional[str] = None,
                             caption: Optional[str] = None,
                             reply_to_message_id: Optional[str | int] = None) -> "Message":
         """This service is used to send document.
@@ -340,9 +341,11 @@ class Bot:
         chat_id: :class:`str` | :class:`int`
                 Unique identifier for the target chat or username of the target channel (in the format @channelusername).
         document: :class:`bytes` | :class:`str` | :class:`bale.Document`
-            File to send. Pass a file_id as String to send a file that exists on the Bale servers (recommended), pass an HTTP URL as a String for Bale to get a file from the Internet, or upload a new one.
+                File to send. Pass a file_id as String to send a file that exists on the Bale servers (recommended), pass an HTTP URL as a String for Bale to get a file from the Internet, or upload a new one.
+        file_name: :class:`str`
+                Additional interface options. file name to send.
         caption: Optional[:class:`str`]
-            Document caption.
+                Document caption.
         reply_to_message_id: Optional[:class:`str` | :class:`int`]
                 Additional interface options. An object for an inline keyboard, custom reply keyboard, instructions to remove reply keyboard or to force a reply from the user.
 
@@ -370,19 +373,34 @@ class Bot:
                 "document param must be type of bytes, str or Document"
             )
 
+        if file_name:
+            if not isinstance(file_name, str):
+                raise TypeError(
+                    "file_name param must be type of str"
+                )
+            if isinstance(document, (str, Document)):
+                raise TypeError(
+                    "file_name param should only be used when you are uploading a file!"
+                )
+
         if reply_to_message_id and not isinstance(reply_to_message_id, Message):
             raise TypeError(
                 "reply_to_message_id param must be type of Message"
             )
 
+        if caption and not isinstance(caption, str):
+            raise TypeError(
+                "caption param must be type of str"
+            )
+
         if isinstance(document, Document):
             document = document.file_id
 
-        response = await self.http.send_document(chat_id, document, caption=caption,
+        response = await self.http.send_document(chat_id, [InputFile('document', file_name, document).to_file_form_payload()], caption=caption,
                                                  reply_to_message_id=reply_to_message_id)
         return Message.from_dict(data=response.result, bot=self)
 
-    async def send_photo(self, chat_id: str | int, photo: bytes | str | "Photo", *, caption: Optional[str] = None,
+    async def send_photo(self, chat_id: str | int, photo: bytes | str | "Photo", *, file_name: Optional[str] = None, caption: Optional[str] = None,
                          reply_to_message_id: Optional[str | int] = None) -> "Message":
         """This service is used to send photo.
 
@@ -392,6 +410,8 @@ class Bot:
                 Unique identifier for the target chat or username of the target channel (in the format @channelusername).
             photo: :class:`bytes` | :class:`str` | :class:`bale.Photo`
                 Photo to send. Pass a file_id as String to send a file that exists on the Bale servers (recommended), pass an HTTP URL as a String for Bale to get a file from the Internet, or upload a new one.
+            file_name: :class:`str`
+                Additional interface options. file name to send.
             caption: Optional[:class:`str`]
                 Photo caption.
             reply_to_message_id: Optional[:class:`str` | :class:`int`]
@@ -424,6 +444,16 @@ class Bot:
         if isinstance(photo, Photo):
             photo = photo.file_id
 
+        if file_name:
+            if not isinstance(file_name, str):
+                raise TypeError(
+                    "file_name param must be type of str"
+                )
+            if isinstance(photo, (str, Photo)):
+                raise TypeError(
+                    "file_name param should only be used when you are uploading a file!"
+                )
+
         if reply_to_message_id and not isinstance(reply_to_message_id, (str, int)):
             raise TypeError(
                 "reply_to_message_id param must be type of str or int"
@@ -434,11 +464,11 @@ class Bot:
                 "caption param must be type of str"
             )
 
-        response = await self.http.send_photo(str(chat_id), photo, caption=caption,
+        response = await self.http.send_photo(str(chat_id), [InputFile('photo', file_name, photo).to_file_form_payload()], caption=caption,
                                               reply_to_message_id=reply_to_message_id)
         return Message.from_dict(data=response.result, bot=self)
 
-    async def send_audio(self, chat_id: str | int, audio: bytes | str | "Audio", *, caption: Optional[str] = None,
+    async def send_audio(self, chat_id: str | int, audio: bytes | str | "Audio", *, file_name: Optional[str] = None, caption: Optional[str] = None,
                          reply_to_message_id: Optional[str | int] = None) -> "Message":
         """This service is used to send Audio.
 
@@ -448,6 +478,8 @@ class Bot:
                 Unique identifier for the target chat or username of the target channel (in the format @channelusername).
             audio: :class:`bytes` | :class:`str` | :class:`bale.Audio`
                 Audio file to send. Pass a file_id as String to send a file that exists on the Bale servers (recommended), pass an HTTP URL as a String for Bale to get a file from the Internet, or upload a new one.
+            file_name: :class:`str`
+                Additional interface options. file name to send.
             caption: Optional[:class:`str`]
                 Audio caption.
             reply_to_message_id: Optional[:class:`str` | :class:`int`]
@@ -480,6 +512,16 @@ class Bot:
         if isinstance(audio, Audio):
             audio = audio.file_id
 
+        if file_name:
+            if not isinstance(file_name, str):
+                raise TypeError(
+                    "file_name param must be type of str"
+                )
+            if isinstance(audio, (str, Audio)):
+                raise TypeError(
+                    "file_name param should only be used when you are uploading a file!"
+                )
+
         if reply_to_message_id and not isinstance(reply_to_message_id, (str, int)):
             raise TypeError(
                 "reply_to_message_id param must be type of str or int"
@@ -490,11 +532,11 @@ class Bot:
                 "caption param must be type of str"
             )
 
-        response = await self.http.send_audio(str(chat_id), audio, caption=caption,
+        response = await self.http.send_audio(str(chat_id), [InputFile('audio', file_name, audio).to_file_form_payload()], caption=caption,
                                               reply_to_message_id=reply_to_message_id)
         return Message.from_dict(data=response.result, bot=self)
 
-    async def send_video(self, chat_id: str | int, video: bytes | str | "Photo", *, caption: Optional[str] = None,
+    async def send_video(self, chat_id: str | int, video: bytes | str | "Photo", *, file_name: Optional[str] = None, caption: Optional[str] = None,
                          reply_to_message_id: Optional[str | int] = None) -> "Message":
         """This service is used to send Video.
 
@@ -504,6 +546,8 @@ class Bot:
                 Unique identifier for the target chat or username of the target channel (in the format @channelusername).
             video: :class:`bytes` | :class:`str` | :class:`bale.Photo`
                 Video to send. Pass a file_id as String to send a file that exists on the Bale servers (recommended), pass an HTTP URL as a String for Bale to get a file from the Internet, or upload a new one.
+            file_name: :class:`str`
+                Additional interface options. file name to send.
             caption: Optional[:class:`str`]
                 Video caption.
             reply_to_message_id: Optional[:class:`str` | :class:`int`]
@@ -536,6 +580,16 @@ class Bot:
         if isinstance(video, Video):
             video = video.file_id
 
+        if file_name:
+            if not isinstance(file_name, str):
+                raise TypeError(
+                    "file_name param must be type of str"
+                )
+            if isinstance(video, (str, Video)):
+                raise TypeError(
+                    "file_name param should only be used when you are uploading a file!"
+                )
+
         if reply_to_message_id and not isinstance(reply_to_message_id, (str, int)):
             raise TypeError(
                 "reply_to_message_id param must be type of str or int"
@@ -546,7 +600,7 @@ class Bot:
                 "caption param must be type of str"
             )
 
-        response = await self.http.send_video(str(chat_id), video, caption=caption,
+        response = await self.http.send_video(str(chat_id), [InputFile('video', file_name, video).to_file_form_payload()], caption=caption,
                                               reply_to_message_id=reply_to_message_id)
         return Message.from_dict(data=response.result, bot=self)
 
