@@ -21,12 +21,13 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
+from typing import Dict, List
 from bale.version import BALE_API_BASE_URL, BALE_API_FILE_URL
 import asyncio
 import aiohttp
-from ..error import (NetworkError, TimeOut, NotFound, Forbidden, APIError, BaleError, HTTPClientError, RateLimited, HTTPException)
+from ..error import (NetworkError, TimeOut, NotFound, Forbidden, APIError, BaleError, HTTPClientError, RateLimited, HTTPException, InvalidToken)
 from .parser import ResponseParser
-from .utils import ResponseStatusCode
+from .utils import ResponseStatusCode, to_json
 
 __all__ = ("HTTPClient", "Route")
 
@@ -64,6 +65,10 @@ class HTTPClient:
 		self._loop: asyncio.AbstractEventLoop = loop
 		self.token = token
 
+	@property
+	def user_agent(self) -> str:
+		return "python-bale-bot (https://python-bale-bot.ir): An API wrapper for Bale written in Python"
+
 	def is_closed(self):
 		return self.__session is None
 
@@ -92,9 +97,29 @@ class HTTPClient:
 			await self.__session.close()
 			self.__session = None
 
-	async def request(self, route: Route, **kwargs):
+	async def request(self, route: Route, *, form: List[Dict] = None, **kwargs):
 		url = route.url
 		method = route.method
+		headers = { 'User-Agent': self.user_agent }
+
+		if 'json' in kwargs:
+			headers['Content-Type'] = 'application/json'
+			kwargs['data'] = to_json(kwargs.pop('json'))
+
+
+		if form:
+			form_data = aiohttp.FormData()
+			for file_payload in form:
+				form_data.add_field(**file_payload, content_type= "multipart/form-data")
+			if 'data' in kwargs:
+				_data = kwargs.pop('data')
+				for param in _data:
+					form_data.add_field(param, _data[param])
+
+			kwargs['data'] = form_data
+
+		kwargs['headers'] = headers
+
 		for tries in range(5):
 			try:
 				async with self.__session.request(method=method, url=url, **kwargs) as response:
@@ -117,6 +142,8 @@ class HTTPClient:
 							continue
 						elif parsed_response.description == HTTPClientError.PERMISSION_DENIED:
 							raise Forbidden()
+						elif parsed_response.description == HTTPClientError.TOKEN_NOT_FOUND:
+							raise InvalidToken()
 
 						raise APIError(
 								str(parsed_response.error_code), parsed_response.description
@@ -165,10 +192,9 @@ class HTTPClient:
 
 		return self.request(Route("POST", "forwardMessage", self.token), json=payload)
 
-	def send_document(self, chat_id, document, *, caption=None, reply_to_message_id=None):
+	def send_document(self, chat_id, form, *, caption=None, reply_to_message_id=None):
 		payload = {
-			"chat_id": chat_id,
-			"document": document
+			"chat_id": chat_id
 		}
 		if caption:
 			payload["caption"] = caption
@@ -176,36 +202,33 @@ class HTTPClient:
 		if reply_to_message_id:
 			payload["reply_to_message_id"] = reply_to_message_id
 
-		return self.request(Route("POST", "Senddocument", self.token), data=payload)
+		return self.request(Route("POST", "sendDocument", self.token), data=payload, form=form)
 
-	def send_photo(self, chat_id, photo, *, caption=None, reply_to_message_id=None):
+	def send_photo(self, chat_id, form, *, caption=None, reply_to_message_id=None):
 		payload = {
-			"chat_id": chat_id,
-			"photo": photo
+			"chat_id": chat_id
 		}
 		if caption:
 			payload["caption"] = caption
 		if reply_to_message_id:
 			payload["reply_to_message_id"] = reply_to_message_id
 
-		return self.request(Route("POST", "SendPhoto", self.token), data=payload)
+		return self.request(Route("POST", "SendPhoto", self.token), data=payload, form=form)
 
-	def send_video(self, chat_id, video, *, caption=None, reply_to_message_id=None):
+	def send_video(self, chat_id, form, *, caption=None, reply_to_message_id=None):
 		payload = {
-			"chat_id": chat_id,
-			"video": video
+			"chat_id": chat_id
 		}
 		if caption:
 			payload["caption"] = caption
 		if reply_to_message_id:
 			payload["reply_to_message_id"] = reply_to_message_id
 
-		return self.request(Route("POST", "sendVideo", self.token), data=payload)
+		return self.request(Route("POST", "sendVideo", self.token), data=payload, form=form)
 
-	def send_audio(self, chat_id, audio, *, caption=None, duration=None, title=None, reply_to_message_id=None):
+	def send_audio(self, chat_id, form, *, caption=None, duration=None, title=None, reply_to_message_id=None):
 		payload = {
-			"chat_id": chat_id,
-			"audio": audio
+			"chat_id": chat_id
 		}
 		if caption:
 			payload["caption"] = caption
@@ -216,7 +239,7 @@ class HTTPClient:
 		if reply_to_message_id:
 			payload["reply_to_message_id"] = reply_to_message_id
 
-		return self.request(Route("POST", "SendAudio", self.token), data=payload)
+		return self.request(Route("POST", "SendAudio", self.token), data=payload, form=form)
 
 	def send_contact(self, chat_id, phone_number, first_name, *, last_name):
 		payload = {
@@ -227,7 +250,7 @@ class HTTPClient:
 		if last_name:
 			payload["last_name"] = last_name
 
-		return self.request(Route("POST", "SendContact", self.token), data=payload)
+		return self.request(Route("POST", "sendContact", self.token), data=payload)
 
 	def send_invoice(self, chat_id, title, description, provider_token, prices, photo_url=None, need_name=False, need_phone_number=False, need_email=False, need_shipping_address=False, is_flexible=True):
 		payload = {"chat_id": chat_id, "title": title, "description": description, "provider_token": provider_token, "prices": prices}
@@ -262,7 +285,7 @@ class HTTPClient:
 			"chat_id": chat_id,
 			"message_id": message_id
 		}
-		return self.request(Route("GET", "deletemessage", self.token), params=payload)
+		return self.request(Route("GET", "deleteMessage", self.token), json=payload)
 
 	def get_updates(self, offset=None, limit=None):
 		payload = {}
@@ -270,31 +293,31 @@ class HTTPClient:
 			payload["offset"] = offset
 		if limit:
 			payload["limit"] = limit
-		return self.request(Route("POST", "getupdates", self.token), json=payload)
+		return self.request(Route("POST", "getUpdates", self.token), json=payload)
 
 	def delete_webhook(self):
 		return self.request(Route("GET", "deleteWebhook", self.token))
 
 	def get_bot(self):
-		return self.request(Route("GET", "getme", self.token))
+		return self.request(Route("GET", "getMe", self.token))
 
 	def get_chat(self, chat_id):
-		return self.request(Route("GET", "getchat", self.token), params=dict(chat_id=chat_id))
+		return self.request(Route("GET", "getChat", self.token), json=dict(chat_id=chat_id))
 
 	def leave_chat(self, chat_id):
-		return self.request(Route("GET", "leaveChat", self.token), params=dict(chat_id=chat_id))
+		return self.request(Route("GET", "leaveChat", self.token), json=dict(chat_id=chat_id))
 
 	def get_chat_administrators(self, chat_id):
-		return self.request(Route("GET", "getChatAdministrators", self.token), params=dict(chat_id=chat_id))
+		return self.request(Route("GET", "getChatAdministrators", self.token), json=dict(chat_id=chat_id))
 
 	def get_chat_members_count(self, chat_id):
-		return self.request(Route("GET", "getChatMemberCount", self.token), params=dict(chat_id=chat_id))
+		return self.request(Route("GET", "getChatMemberCount", self.token), json=dict(chat_id=chat_id))
 
 	def get_chat_member(self, chat_id, member_id):
-		return self.request(Route("GET", "getChatMember", self.token), params=dict(chat_id=chat_id, user_id=member_id))
+		return self.request(Route("GET", "getChatMember", self.token), json=dict(chat_id=chat_id, user_id=member_id))
 
 	def ban_chat_member(self, chat_id, member_id):
-		return self.request(Route("POST", "banChatMember", self.token), params=dict(chat_id=chat_id, user_id=member_id))
+		return self.request(Route("POST", "banChatMember", self.token), json=dict(chat_id=chat_id, user_id=member_id))
 
 	def invite_to_chat(self, chat_id, user_id):
-		return self.request(Route("GET", "InviteUser", self.token), json=dict(chat_id=chat_id, user_id=user_id))
+		return self.request(Route("GET", "inviteUser", self.token), json=dict(chat_id=chat_id, user_id=user_id))
